/****************************************************************************
** Meta object code from reading C++ file 'dboxwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dboxwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dboxwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DBoxWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DBoxWidget",
        "sizeChanged",
        "",
        "QSize",
        "size",
        "directionChanged",
        "QBoxLayout::Direction",
        "direction",
        "setDirection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(QSize)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'directionChanged'
        QtMocHelpers::SignalData<void(QBoxLayout::Direction)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'setDirection'
        QtMocHelpers::SlotData<void(QBoxLayout::Direction)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'direction'
        QtMocHelpers::PropertyData<QBoxLayout::Direction>(7, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBoxWidget, qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk6Widget10DBoxWidgetE[] = {
    QMetaObject::SuperData::link<QBoxLayout::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Widget::DBoxWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk6Widget10DBoxWidgetE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DBoxWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBoxWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 1: _t->directionChanged((*reinterpret_cast<std::add_pointer_t<QBoxLayout::Direction>>(_a[1]))); break;
        case 2: _t->setDirection((*reinterpret_cast<std::add_pointer_t<QBoxLayout::Direction>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBoxWidget::*)(QSize )>(_a, &DBoxWidget::sizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBoxWidget::*)(QBoxLayout::Direction )>(_a, &DBoxWidget::directionChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QBoxLayout::Direction*>(_v) = _t->direction(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDirection(*reinterpret_cast<QBoxLayout::Direction*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DBoxWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DBoxWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget10DBoxWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QFrame::qt_metacast(_clname);
}

int Dtk::Widget::DBoxWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DBoxWidget::sizeChanged(QSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DBoxWidget::directionChanged(QBoxLayout::Direction _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DHBoxWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DHBoxWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DHBoxWidget, qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DHBoxWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DBoxWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DHBoxWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DHBoxWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::DHBoxWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DHBoxWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DHBoxWidgetE_t>.strings))
        return static_cast<void*>(this);
    return DBoxWidget::qt_metacast(_clname);
}

int Dtk::Widget::DHBoxWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBoxWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DVBoxWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DVBoxWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DVBoxWidget, qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DVBoxWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DBoxWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DVBoxWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DVBoxWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::DVBoxWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DVBoxWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DVBoxWidgetE_t>.strings))
        return static_cast<void*>(this);
    return DBoxWidget::qt_metacast(_clname);
}

int Dtk::Widget::DVBoxWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBoxWidget::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
